@@ -116,3 +116,19 @@ for (var i = 0; i < internalLinks.length; i++) {
     }, 1200);
   };
 }
+
+/**
+ * 
+ * Use images title as caption
+ */
+for (var i = 0; i < images.length; i++) {
+  var image = images[i];
+  var title = images[i].getAttribute('title');
+  if(title) {
+    console.log(title);
+    var imageContainer = image.parentNode;
+    var caption = document.createElement('figcaption');
+    caption.innerHTML = title;
+    imageContainer.insertBefore(caption, image.nextSibling);
+  }
+}
\ No newline at end of file
